class Metadata:
    def __init__(self):
        self.writing_style = "formal"
        self.target_audience = "general public"
        self.tone = "neutral"
        self.background_context = "none provided"
        self.generation_directive = "use good grammar.  Be concise and clear."
        self.word_limit = 250
        self.source = ""
        self.model = ""