"""Writing Assistant - AI-powered document generation tool."""

__version__ = "0.1.0"
__author__ = "Travis Bauer"
__email__ = "tlbauer@sandia.gov"

from .core.definitions import Metadata

__all__ = ["Metadata"]